#!/usr/bin/env python3

"""
NAME:
	secondary-zones.py - generate secondary.zones

SYNOPSIS:
	secondary-zones.py ["primaries" ...]

DESCRIPTION:
	This script reads bind-9 primary zone definitions from stdin and
	outputs secondary zone ones.

        We use the list of 'primaries' in config or taken from command
        line.

	Basically, each 'primary' zone is replaced with a
	'secondary' zone with "primaries" being the address to do zone
	transfers from.

AUTHOR:
	Simon J. Gerraty <sjg@crufty.net>
"""

"""
RCSid:
	$Id: secondary-zones.py,v 1.4 2023/06/05 16:08:27 sjg Exp $

	@(#) Copyright (c) 1997-2023 Simon J. Gerraty.

	This file is provided in the hope that it will
	be of use.  There is absolutely NO WARRANTY.
	Permission to copy, redistribute or otherwise
	use this file is hereby granted provided that 
	the above copyright notice and this notice are
	left intact. 
      
	Please send copies of changes and bug-fixes to:
	sjg@crufty.net
"""


import sys
import os
import os.path
import time
import dnsutils
import conf as cf

def secondary_zones(conf={}):

    print(cf.subst('// generated by ${progdir}/${progname}', conf))
    print('// DO NOT EDIT!!!!')
    
    inf = conf.get('inf', sys.stdin)
    for line in inf.readlines():
        w = line.strip().split()
        if len(w) > 1:
            if w[0] == 'zone':
                zone = w[1].strip('"')
                if zone.endswith('in-addr.arpa'):
                    a = zone.strip('.in-addr.arpa').split('.')
                    a.reverse()
                    zone = '.'.join(a)
            elif w[1] == 'primary;':
                print('\ttype secondary; primaries {{ {}; }};'.format(';'.join(conf['primaries'])))
                print('\tfile "secondary/{}";'.format(zone))
                continue
            elif w[0] in ['allow-update', 'file']:
                continue
        print(line, end='')

def myopts(o,a,conf):

    if o == '-i':
        conf['inf'] = open(a, 'r')

if __name__ == '__main__':

    conf = {
        'DEBUG': {},
        }

    conf,args = dnsutils.app_init('i:', myopts, conf)

    if not 'primaries' in conf:
        conf['primaries'] = args
    secondary_zones(conf)
    sys.exit(0)
