:
# NAME:
#	upd_inaddr.sh - create list of in-addr delegations
#
# SYNOPSIS:
#	upd_inaddr.sh "NDBOOT" ["DATA" ["ND_DATA"]]
#
# DESCRIPTION:
#	We extract primary/secondary in-addr zone records from
#	named.boot (or named.conf converted to that format) and
#	produce a delegation list.
#
#	We only use/need this on an internal root nameserver.
#	If "ND_DATA" (output from getdata.pl(8)) exists  we
#	simply grep all the NS records for secondary zones from it.
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

# RCSid:
#	$Id: upd_inaddr.sh,v 1.7 2022/10/10 00:39:06 sjg Exp $
#
#	@(#) Copyright (c) 1997-2022 Simon J. Gerraty.
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

Mydir=`dirname $0`
PATH=$PATH:$Mydir
export PATH

NDBOOT=${1:-/etc/named.boot}
DATA=${2:-in-addr.arpa}
ND_DATA=${3:-/dev/null}
NS_LIST=${NS_LIST:-ns.list}

case "$NS_LIST" in
/*) INS_LIST=`basename $NS_LIST`;;
*) INS_LIST=$NS_LIST;;
esac

( case $NDBOOT in
*named*conf*)
        ndconv.sh  $NDBOOT;;
*)
        cat $NDBOOT;;
esac ) | grep -i '^[ps].*in-addr' | tr 'A-Z' 'a-z' |
	awk '{ print $1, $2, $NF }' - |
while read role zone file
do
        case $role in
	primary)
                if [ -s $NS_LIST ]; then
        	        echo "\$INCLUDE $INS_LIST $zone."
                        continue
		fi
                ;;
	esac
	# if ND_DATA (output from getdata) exists, use it.
        if test -s $ND_DATA; then
		grep "NS $zone " $ND_DATA | sed 's/^NS \([^ ]*\) \([^ ][^ ]*\)/\1. IN NS \2./'
	else
	        # do it the hard way
		awk 'BEGIN { lorigin="never"; }
/^.ORIGIN/ { origin=$0; at="@"; }
/^[^0-9].*IN.*SOA/ { at="@"; }
/^[0-9].*IN.*SOA/ { at=$1; }
/^[0-9].*IN.*NS/ { at=""; if (lorigin != origin) {
		printf("%s\n", origin)
		origin=origin
	}
	printf("%s\n", $0);
}
/^[^0-9].*IN.*NS/ { if (lorigin != origin) {
		printf("%s\n", origin)
		lorigin=origin
                nns=0
	}
        nns++
  	printf("%s%s\n", at, $0)
}' $file
	fi
done | sed 's/\.\.*/./g' > $DATA.new

install_new.sh $DATA 
